An object of class "Rm", a fitted Rasch model or partial
credit model using the functions RM or PCM in package eRm, or an object of class "pcmodel",
a fitted partial credit model using the function pcmodel in package psychotools.
properties
If TRUE additional properties of the estimates are given (see below).
allperson
If TRUE person estimates (MLE and WLE) for all persons in the data set are delivered.
Value
If properties = False a matrix containing:
Raw score
raw score
MLE
MLE of person parameters
WLE
WLE of person parameters
If properties = TRUE a list with two components, one for MLE and the other for WLE. Each component
contains:
Raw score
raw score
MLE or WLE
person estimates
SEM
standard error of measurement
Bias
bias
RMSE
root mean square error
Score.SEM
score sem
References
Christensen, K. B. , Kreiner, S. & Mesbah, M. (Eds.)
Rasch Models in Health. Iste and Wiley (2013), pp. 63 - 70.