partgam_LD: Partial Gamma to detect Local Dependence (LD)
Description
Rasch models assume locally independent items. There should be no substantial correlation left between two items
once the underlying factor has been taken into account.
Partial Gamma coefficients between pairs of items controlled for the rest score
can be used to assess this requirement.
Usage
partgam_LD(dat.items)
Arguments
dat.items
A data frame with the responses to the items.
Value
data frame with Gamma coefficients, standard errors, p values and confidence limits for every
pair of items.
References
Christensen, K. B. , Kreiner, S. & Mesbah, M. (Eds.)
Rasch Models in Health. Iste and Wiley (2013), pp. 133 - 135.